@@ -17,6 +17,7 @@ from .pygeoutils import (
     arcgis2geojson,
     break_lines,
     geo2polygon,
+    geometry_list,
     get_gtiff_attrs,
     get_transform,
     gtiff2xarray,
@@ -27,19 +28,19 @@ from .pygeoutils import (
 )
 
 try:
-    import importlib.metadata as metadata
+    import importlib.metadata
 except ImportError:
-    import importlib_metadata as metadata  # type: ignore[no-redef]
+    import importlib_metadata
 
-try:
-    __version__ = metadata.version("pygeoutils")
-except Exception:
-    __version__ = "999"
+    __version__ = importlib_metadata.version("pygeoutils")
+else:
+    __version__ = importlib.metadata.version("pygeoutils")
 
 __all__ = [
     "arcgis2geojson",
     "break_lines",
     "geo2polygon",
+    "geometry_list",
     "get_gtiff_attrs",
     "get_transform",
     "gtiff2xarray",
